@@ -1,4 +1,5 @@
 from django.db.models import Model
+from django.db.models.fields.related import RelatedField
 from django.forms.models import ModelForm
 
 
@@ -10,7 +11,10 @@ class PartitialForm(ModelForm):
             if kwargs.get(name):
                 value = kwargs.get(name)
                 data[name] = value if not isinstance(value, Model) else value.pk
-            elif instance and getattr(instance, name) and not data.has_key(name):
-                value = getattr(instance, name)
-                data[name] = value if not isinstance(value, Model) else value.pk
+            elif instance and not data.has_key(name):
+                field = instance._meta.get_field(name)
+                if isinstance(field, RelatedField):
+                    data[name] = getattr(instance, '%s_id' % name)
+                else:
+                    data[name] = getattr(instance, name)
         self.data = data
